Crate samod_core

Re-exports

pub use actors::hub::CommandId;
pub use actors::hub::CommandResult;
pub use network::ConnectionId;
pub use actors::document::DocumentActorId;

Modules

actors
io
network

Structs

AutomergeUrl
BadDocumentId
DocumentChanged
DocumentId
Unique identifier for an automerge document.
PeerId
Unique identifier for a peer in the sync network.
SamodLoader
A state machine for loading a samod repository.
StorageId
StorageKey
A hierarchical key for storage operations in the samod-core system.
UnixTimestamp

Enums

LoaderState
The current state of the loader.
PeerIdError
StorageIdError