pub struct DocActorResult {
pub io_tasks: Vec<IoTask<DocumentIoTask>>,
pub outgoing_messages: Vec<DocToHubMsg>,
pub ephemeral_messages: Vec<Vec<u8>>,
pub change_events: Vec<DocumentChanged>,
pub stopped: bool,
pub peer_state_changes: HashMap<ConnectionId, PeerDocState>,
pub sync_message_stats: Vec<SyncMessageStat>,
pub pending_sync_messages: usize,
}Expand description
Result of processing a message or I/O completion.
Fields
io_tasks: Vec<IoTask<DocumentIoTask>>Document I/O tasks that need to be executed by the caller.
outgoing_messages: Vec<DocToHubMsg>Messages to send back to the main system.
ephemeral_messages: Vec<Vec<u8>>New ephemeral messages
change_events: Vec<DocumentChanged>Change events
stopped: boolWhether this document actor is stopped
peer_state_changes: HashMap<ConnectionId, PeerDocState>Connections which have changed state for this document
sync_message_stats: Vec<SyncMessageStat>Sync message statistics for observability
pending_sync_messages: usizeNumber of pending sync messages queued during Loading phase
Implementations