pub enum PeerRequestState {
Requested,
Unavailable,
Syncing,
Available,
}Expand description
State of searching with a specific peer.
Variants
Requested
We’ve asked this peer and are waiting for a response.
This peer doesn’t have the document.
Syncing
We’re syncing the document from this peer.
Available
The peer has the document and we are in sync (Ready phase, idle).