pub struct ConnectionInfo {
pub id: ConnectionId,
pub last_received: Option<UnixTimestamp>,
pub last_sent: Option<UnixTimestamp>,
pub docs: HashMap<DocumentId, PeerDocState>,
pub state: ConnectionState,
}Expand description
Information about each live connection
Fields
id: ConnectionIdlast_received: Option<UnixTimestamp>last_sent: Option<UnixTimestamp>docs: HashMap<DocumentId, PeerDocState>The state of each document we are synchronizing with this peer
state: ConnectionStateWhether we are handshaking or connected with this peer