pub struct DialerConfig {
pub url: Url,
pub backoff: BackoffConfig,
}Expand description
Configuration for a new dialer.
A dialer actively establishes outgoing connections and automatically reconnects with exponential backoff when a connection is lost.
Fields
url: UrlThe URL to connect to (e.g. “wss://sync.example.com/automerge”).
backoff: BackoffConfigBackoff configuration for reconnection attempts.