pub struct DialerId(/* private fields */);Expand description
A unique identifier for a dialer in the samod-core system.
A dialer represents a persistent outgoing connection that automatically reconnects with backoff. Each dialer has at most one active connection at a time.