pub struct PeerDocState {
pub last_received: Option<UnixTimestamp>,
pub last_sent: Option<UnixTimestamp>,
pub last_sent_heads: Option<Vec<ChangeHash>>,
pub last_acked_heads: Option<Vec<ChangeHash>>,
}Expand description
The state of synchronization for one (peer, document) pair
Fields
last_received: Option<UnixTimestamp>When we last received a message from this peer
last_sent: Option<UnixTimestamp>When we last sent a message to this peer
last_sent_heads: Option<Vec<ChangeHash>>The heads of the document when we last sent a message
last_acked_heads: Option<Vec<ChangeHash>>The last heads of the document that the peer said they had