pub struct PeerId(/* private fields */);Expand description
Unique identifier for a peer in the sync network.
Peer IDs are ephemeral identifiers that identify a specific instance of a peer (e.g., a browser tab, a process). They are UTF-8 strings that are different from storage IDs which identify the underlying storage.
Implementations
Sourceimpl PeerId
impl PeerId
Sourcepub fn new_with_rng<R: Rng>(rng: &mut R) -> Self
pub fn new_with_rng<R: Rng>(rng: &mut R) -> Self
Creates a new peer ID with a generated value using the provided RNG.
Sourcepub fn from_string(s: String) -> Self
pub fn from_string(s: String) -> Self
Creates a peer ID from a string.
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Returns the peer ID as a String.