Re-exports
pub use actors::hub::CommandId;pub use actors::hub::CommandResult;pub use network::ConnectionId;pub use actors::document::DocumentActorId;
Modules
Structs
- Automerge
Url - BadDocument
Id - Document
Changed - Document
Id - Unique identifier for an automerge document.
- PeerId
- Unique identifier for a peer in the sync network.
- Samod
Loader - A state machine for loading a samod repository.
- Storage
Id - Storage
Key - A hierarchical key for storage operations in the samod-core system.
- Unix
Timestamp
Enums
- Loader
State - The current state of the loader.
- Peer
IdError - Storage
IdError