Skip to main contentModule network
Source - BackoffConfig
- Configuration for exponential backoff with jitter.
- ConnectionId
- A unique identifier for network connections in the samod-core system.
- ConnectionInfo
- Information about each live connection
- DialRequest
- A request for the IO layer to establish a new transport for a dialer.
- DialerConfig
- Configuration for a new dialer.
- DialerId
- A unique identifier for a dialer in the samod-core system.
- ListenerConfig
- Configuration for a new listener.
- ListenerId
- A unique identifier for a listener in the samod-core system.
- PeerDocState
- The state of synchronization for one (peer, document) pair
- PeerInfo
- Information about a connected peer after successful handshake.
- PeerMetadata
- Metadata about a peer from the handshake.
- ConnDirection
- Indicates whether a connection was initiated locally or received from a remote peer
- ConnectionEvent
- Events related to connection lifecycle and handshake process.
- ConnectionOwner
- Identifies which dialer or listener owns a connection.
- ConnectionState
- DialerEvent
- Events related to dialer lifecycle.