Module network
Source - ConnectionId
- A unique identifier for network connections in the samod-core system.
- ConnectionInfo
- Information about each live connection
- PeerDocState
- The state of synchronization for one (peer, document) pair
- PeerInfo
- Information about a connected peer after successful handshake.
- PeerMetadata
- Metadata about a peer from the handshake.
- ConnDirection
- Indicates whether a connection was initiated locally or received from a remote peer
- ConnectionEvent
- Events related to connection lifecycle and handshake process.
- ConnectionState